Index: lib/src/runner/browser/compiler_pool.dart |
diff --git a/lib/src/runner/browser/compiler_pool.dart b/lib/src/runner/browser/compiler_pool.dart |
index a424151af93fda56f221f1d07a48e93a325f7f07..0e89690c38d8bf71880fc36f5bf15c76374904c9 100644 |
--- a/lib/src/runner/browser/compiler_pool.dart |
+++ b/lib/src/runner/browser/compiler_pool.dart |
@@ -41,14 +41,14 @@ class CompilerPool { |
/// The completer for the [Future] returned by [close]. |
Completer _closeCompleter; |
/// Creates a compiler pool that runs up to [parallel] instances of `dart2js` |
/// at once. |
/// |
/// If [parallel] isn't provided, it defaults to 4. |
/// |
/// If [color] is true, `dart2js` will be run with colors enabled. |
- CompilerPool({int parallel, bool color: false}) |
- : _pool = new Pool(parallel == null ? 4 : parallel), |
+ CompilerPool({int concurrency, bool color: false}) |
+ : _pool = new Pool(concurrency == null ? 4 : concurrency), |
_color = color; |
/// Compile the Dart code at [dartPath] to [jsPath]. |
@@ -41,14 +41,14 @@ class CompilerPool { |
/// The completer for the [Future] returned by [close]. |
Completer _closeCompleter; |
- /// Creates a compiler pool that runs up to [parallel] instances of `dart2js` |
- /// at once. |
+ /// Creates a compiler pool that runs up to [concurrency] instances of |
+ /// `dart2js` at once. |
/// |
@@ -41,14 +41,14 @@ class CompilerPool { |
/// |
- /// If [parallel] isn't provided, it defaults to 4. |
+ /// If [concurrency] isn't provided, it defaults to 4. |
/// |
/// If [color] is true, `dart2js` will be run with colors enabled. |